@@ -3,7 +3,7 @@ package CGI::OptimalQuery::CustomOutput;
 use strict;
 use warnings;
 no warnings qw( uninitialized );
-use base 'CGI::OptimalQuery::AbstractQuery';
+use base 'CGI::OptimalQuery::Base';
 use CGI();
 
 our $custom_output_handler;
